@@ -527,7 +527,7 @@ def get_ldap_flat_membership(l, search_strings, list_name, max_depth, depth=0, s
             else:
                 seen_lists.add(sub_list)
             sub_list_members = get_ldap_flat_membership(l, search_strings, sub_list, max_depth, new_depth, seen_lists)
-            logger.info('Found %s from %s (depth %s/%s)', len(sub_list_members), email, new_depth, max_depth)
+            logger.debug('Found %s from %s (depth %s/%s)', len(sub_list_members), email, new_depth, max_depth)
             members |= sub_list_members
 
     return members
@@ -727,8 +727,13 @@ def main():
     except ValueError:
         nap_time = default_nap_time
 
-    engine = create_engine(config['db']['conn']['str'] % config['db']['conn']['kwargs'],
-                           **config['db']['kwargs'])
+    # check if we are using special connection settings for this script
+    if config.get('db_target_sync'):
+        engine = create_engine(config['db_target_sync']['conn']['str'] % config['db_target_sync']['conn']['kwargs'],
+                               **config['db_target_sync']['kwargs'])
+    else:
+        engine = create_engine(config['db']['conn']['str'] % config['db']['conn']['kwargs'],
+                               **config['db']['kwargs'])
 
     # Optionally, maintain an internal list of mailing lists from ldap that can also be
     # used as targets.
